clear
use "../Analysis Data/Analysis.dta"

***ANALYSIS DO FILE 

*create table 1: summary statistics (pg. 23)
summarize turnover rostercont catchcont sscont startpitchcont warexists sigrate warpersig leagueturnover WL pythWL

*NOTE: After final, fully specified regression, I include robustness tests, 
*the results of which are cited throughout the paper
*NOTE: Regressions are listed in order of Models...(Model 1, then Model 2, etc)
*create table 2: Quadratic Estimate of the Effect of General Turnover on Win % (pg. 33)
gen turn2=turnover*turnover
gen logpayroll=log(teampayroll)
regress WL turnover turn2 man_tenure 
regress WL turnover turn2 man_tenure warpersig 
regress WL turnover turn2 man_tenure warpersig sigrate  
regress WL turnover turn2 man_tenure warpersig sigrate logpayroll 
regress WL turnover turn2 man_tenure warpersig sigrate logpayroll L.WL 
estat vif 
estat hettest 
xtreg WL turnover turn2 man_tenure warpersig sigrate logpayroll L.WL, fe


*create Table 3: OLS estimate of the Effect of General Turnover on Win % (pg. 34)
regress WL turnover man_tenure 
regress WL turnover man_tenure warpersig 
estat vif 
estat hettest
regress WL turnover man_tenure warpersig sigrate  
regress WL turnover man_tenure warpersig sigrate logpayroll 
regress WL turnover man_tenure warpersig sigrate logpayroll L.WL 
*tests used in robustness appendix (1)
estat vif
estat hettest 
xtreg WL turnover man_tenure warpersig sigrate logpayroll L.WL, fe
*note:center variables and create interaction term
summarize WL, meanonly 
gen cen_WL=WL-r(mean) 
summarize turnover, meanonly 
gen cen_turnover=turnover-r(mean) 
gen WLint=L.cen_WL*cen_turnover
*continute with table: models 7 and 8 
regress WL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_WL WLint
*tests used in robustness appendix (2)
estat vif 
estat hettest 
xtreg WL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_WL WLint,fe


*create Table 4: OLS Estimates of the Effects of Positional Turnover on Win % (pg. 39)
regress WL catchcont sscont startpitchcont man_tenure warpersig sigrate logpayroll L.WL 
*tests used in robustness appendix (4)
estat vif 
estat hettest 
regress WL catchcont man_tenure warpersig sigrate logpayroll L.WL
regress WL sscont man_tenure warpersig sigrate logpayroll L.WL
regress WL startpitchcont man_tenure warpersig sigrate logpayroll L.WL
xtreg WL catchcont sscont startpitchcont man_tenure warpersig sigrate logpayroll L.WL, fe 

*create Table 5: OLS Estimates of the Effects of Park Factors and League Turnover on Win % (pg. 40)
summarize parkfactor, meanonly 
gen cen_parkfactor=parkfactor-r(mean) 
gen parkint=cen_parkfactor*cen_turnover
regress WL leagueturnover cen_turnover cen_parkfactor parkint man_tenure warpersig sigrate logpayroll L.WL
*tests used in robustness appendix (5)
estat vif 
estat hettest
regress WL cen_turnover cen_parkfactor parkint man_tenure warpersig sigrate logpayroll L.WL
estat vif 
estat hettest
regress WL leagueturnover man_tenure warpersig sigrate logpayroll L.WL
estat vif 
estat hettest
xtreg WL leagueturnover man_tenure warpersig sigrate logpayroll L.WL, fe

*****create Table 6: Measuing Turnover Using Roster Continuity (pg. 42) 
*create necessary variables
gen rostercont2=rostercont*rostercont
summarize rostercont, meanonly
gen cen_rostercont=rostercont-r(mean) 
gen rostercontint=cen_rostercont*L.cen_WL 
*run models
regress WL rostercont rostercont2 man_tenure warpersig sigrate logpayroll L.WL 
estat vif
estat hettest 
xtreg WL rostercont rostercont2 man_tenure warpersig sigrate logpayroll L.WL, fe
regress WL rostercont man_tenure warpersig sigrate logpayroll L.WL 
estat vif
estat hettest 
xtreg WL rostercont man_tenure warpersig sigrate logpayroll L.WL, fe
regress WL cen_rostercont man_tenure warpersig sigrate logpayroll L.cen_WL rostercontint
estat vif
estat hettest 
xtreg WL cen_rostercont man_tenure warpersig sigrate logpayroll L.cen_WL rostercontint, fe
 
*create Table 7: Replacing Win % t-1 with Pythagorean Expectation Win % t-1 (pg. 43)
*create necessary variables
summarize pythWL, meanonly
gen cen_pythWL=pythWL-r(mean) 
gen pythWLint=cen_turnover*L.cen_pythWL 
*run models 
regress WL turnover turn2 man_tenure warpersig sigrate logpayroll L.pythWL 
estat vif
estat hettest 
xtreg WL turnover turn2 man_tenure warpersig sigrate logpayroll L.pythWL, fe 
regress WL turnover man_tenure warpersig sigrate logpayroll L.pythWL 
estat vif
estat hettest 
xtreg WL turnover man_tenure warpersig sigrate logpayroll L.pythWL, fe 
regress WL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_pythWL pythWLint
estat vif
estat hettest 
xtreg WL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_pythWL pythWLint, fe 

***create Table 8: Using Vegas Over/Under Win Predictions to control for Team Quality (pg.44)
*create necessary variables 
summarize vegasW, meanonly 
gen cen_vegasW=vegasW-r(mean) 
gen vegasWint=cen_turnover*cen_vegasW
*run models 
regress WL turnover turn2 man_tenure vegasW 
estat vif
estat hettest 
xtreg WL turnover turn2 man_tenure vegasW, fe 
regress WL turnover man_tenure vegasW 
estat vif
estat hettest 
xtreg WL turnover man_tenure vegasW, fe 
regress WL cen_turnover man_tenure cen_vegasW vegasWint
estat vif
estat hettest 
xtreg WL cen_turnover man_tenure cen_vegasW vegasWint, fe 

***create Table 9: Using All Star Break Win % as Dependent Variable (pg. 45)
regress AllStarWL turnover turn2 man_tenure warpersig sigrate logpayroll L.WL 
estat vif 
estat hettest 
xtreg AllStarWL turnover turn2 man_tenure warpersig sigrate logpayroll L.WL, fe
regress AllStarWL turnover man_tenure warpersig sigrate logpayroll L.WL 
estat vif
estat hettest 
xtreg AllStarWL turnover man_tenure warpersig sigrate logpayroll L.WL, fe
regress AllStarWL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_WL WLint
*tests used in robustness appendix (3)
estat vif 
estat hettest 
xtreg AllStarWL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_WL WLint,fe

****create Graph 1:  Win % Distribution by Team (pg. 37) 
graph hbox WL, over(team)



****create Graph 2: All Star Win % vs. Turnover by Quartiles of Past Winning Percentage (pg. 46)
*create variable for quartiles of Lagged Win %
egen fourWL=cut(L.WL), group(4) 
*generate fitted values of AllStar WL 
regress AllStarWL cen_turnover man_tenure warpersig sigrate logpayroll L.cen_WL WLint
predict fv 
*create graph 
twoway (lfit fv turnover), ytitle(AllStarWL Fitted Values) by(fourWL)

*Note: further edits were made using graph editor 

****END OF ANALYSIS 


















