***COMBINING PITCHING PLAYER VALUE ORIGINAL DATA FILES FROM EVERY YEAR SO THEY CAN BE FOUND IN ONE SINGLE DATA FILE

****WORKING DIRECTORY SHOULD BE ON COMMAND FILES FOLDER******

*Clear any data that are in memory so that we start with an
*empty data set

clear

*Create temporary folder where data can be combined before being moved to analysis

capture mkdir ../Temp

*Create Loop so we can do the same thing to all pitching data files 
forvalues yr=2002/2016{

	insheet using "../Original Data/Player Value Data By Year Pitchers/EDITED 2TM leagues_MLB_`yr'-value-pitching_players_value_pitching.csv", names
	*Create a variable "year" that, for each data point, corresponds to the year to which the original data files refer
	gen year=`yr'
	*Then save the new files to the temporary folders 
	save "../Temp/pitch`yr'.dta" , replace
	drop _all

}	

*Now We will merge each of these data files into one file
*The variable Year was created above so that we will be able to tell 
*which data point corresponds to which original data file

clear
use ../Temp/pitch2002.dta

forvalues x=2003/2016{
	append using ../Temp/pitch`x'.dta
}

*Get rid of all asterisks and hashtags in names 
gen test=substr(name,length(name),1)
gen _name=name
replace name=substr(name,1,length(name)-1) if test=="*" | test=="#"
*Get rid of all sub-headers 
drop if name=="Name"
*Drop all extraneous variables 
drop ra9 ra9opp ra9def ra9role ppfp ra9avg raa gmli rar acquired test _name 
*Label the variable year, "YEAR" 
label variable year "Year"
*Drop all non-qualifying players (Less than 40 appearances or 15 starts) 
destring g, replace
destring gs,replace
keep if g>=40 | gs>=15


generate pitcher=1


*Save combined data file for all individual pitcher player value data 
save ../Temp/pitchvalue.dta, replace

***COMBINING HITTER PLAYER VALUE ORIGINAL DATA FILES FROM EVERY YEAR SO THEY CAN BE FOUND IN ONE SINGLE DATA FILE

*Clear any data that are in memory so that we start with an
*empty data set

clear

*Create Loop so we can do the same thing to all batting data files 
forvalues yr=2002/2016{

	insheet using "../Original Data/Player Value Data By Year Hitters/EDITED 2TM leagues_MLB_`yr'-value-batting_players_value_batting.csv", names
	*Create a variable "year" that, for each data point, corresponds to the year to which the original data files refer
	gen year=`yr'
	*Then save the new files to the temporary folders 
	save "../Temp/hit`yr'.dta" , replace
	drop _all

}	

*Now We will merge each of these data files into one file
*The variable Year was created above so that we will be able to tell 
*which data point corresponds to which original data file

clear
use ../Temp/hit2002.dta

forvalues x=2003/2016{
	append using ../Temp/hit`x'.dta
}

*Get rid of all asterisks and hashtags in names 
gen test=substr(name,length(name),1)
gen _name=name
replace name=substr(name,1,length(name)-1) if test=="*" | test=="#"
*Get rid of all sub-headers 
drop if name=="Name"
*Drop all extraneous variables 
drop rbat rbaser rdp rfield rpos raa rrep rar owar dwar orar acquired test _name
*Label the variable year, "YEAR" 
label variable year "Year"
*Drop all non-qualifying players (Less than 100 appearances) 
destring g, replace
keep if g>=100

generate pitcher=0

*Save combined data file for all individual hitter player value data 
save ../Temp/hitvalue.dta, replace



***NOW WE WANT TO MERGE THE TWO COMBINED FILES, hitvalue.dta and pitchvalue.dta 
***TOGETHER to get one playervalue file 

clear                           
*First upload the pitchvalue file to STATA
use "../Temp/pitchvalue.dta"
*Then merge it with the hitvalue file in the Temp folder
*Since no pitcher has pitched 100 games from 2002-2016 and since we are only 
*concerned with hitters who played 100 games or more, we can use game as the key 
*variable and there will be no matches when the two files are merged 
merge m:m g using "../Temp/hitvalue.dta"
*We will see that there are no matches 
*We can now delete the data _merge variable
drop _merge
*We can now change the labels for the variable tm so that they are consistent
*for teams whose names changed between 2002 and 2016
replace tm = "TBR" if tm == "TBD"
replace tm = "WSN" if tm == "MON"
replace tm = "LAA" if tm == "ANA" 
replace tm = "MIA" if tm == "FLA"
replace tm = "ARI" if tm == "ARIZ" 
*unstring team variable so it can be more easily analyzed later on 
*Drop all other non qualifying players
drop if tm =="2TM" 
drop if tm =="3TM"

*unstring team variable so it can be more easily analyzed later on 
encode tm, gen(team)
drop tm 

*drop rank variable
drop rk

*destring war and age
destring war, replace
destring age, replace 

rename name cname 

*Clean up dataset to differentiate between players of the same name
replace cname="Abraham Nunez-a" if cname=="Abraham Nunez" & team==12
replace cname="Alex Scott Gonzalez" if cname=="Alex Gonzalez" & team==5
replace cname="Alex Scott Gonzalez" if cname=="Alex Gonzalez" & team==27
replace cname="Chris R. Young" if cname=="Chris Young" & g<99
replace cname="Chris W. Carter" if cname=="Chris Carter" & team==18
replace cname="Eric Young Jr" if cname=="Eric Young" & team==18
replace cname="Luis E. Gonzalez" if cname=="Luis Gonzalez" & age>30
replace cname="Brian James Anderson" if cname=="Brian Anderson" & g<99
replace cname="Adam Eaton-b" if cname=="Adam Eaton" & g<99
replace cname="Ramon Pena" if cname=="Tony Pena" & g<99
replace cname="Roberto Hernandez-b" if cname=="Roberto Hernandez" & g<40
replace cname="Francisco Rodriguez-b" if cname=="Francisco Rodriguez" & team==13 & year==2010
*Now we want to save the merged data file in the analysis data folder 
save "../Temp/playervalue.dta", replace

/*
*Create a summary statistic data file for total war for each team in a given year
/*egen team_id=group(team year)*/
collapse (mean) age (sum) war, by(team year)
*Save dataset to merge with hand collected data later
save "../Temp/summaryfinalrosterplayervalue.dta", replace
*/




